@@ -17,15 +17,18 @@ MAX_RESULTS = 200
 
 
 def get_min_ledger_index():
-    transactions = Transaction.objects.filter(status__in=[Transaction.RECEIVED, Transaction.PROCESSED,
-                                                          Transaction.MUST_BE_RETURN, Transaction.RETURNING,
-                                                          Transaction.RETURNED]).order_by('-pk')
+    transactions = Transaction.objects.filter(status__in=[
+            Transaction.RECEIVED, Transaction.PROCESSED,
+            Transaction.MUST_BE_RETURN, Transaction.RETURNING,
+            Transaction.RETURNED
+            ]).order_by('-pk')
     return transactions[0].ledger_index if transactions else -1
 
 
 class Command(NoArgsCommand):
     help = 'Command that processes transactions.'
     logger = logging.getLogger('ripple')
+    logger.setLevel(40)
 
     def format_log_message(self, message, transaction=None, *args):
         if transaction or args:
@@ -36,7 +39,7 @@ class Command(NoArgsCommand):
             return message
 
     def handle_noargs(self, **options):
-        self.retry_failed_transactions()
+        #self.retry_failed_transactions()
         self.monitor_transactions()
         self.submit_pending_transactions()
         self.check_submitted_transactions()
@@ -47,14 +50,21 @@ class Command(NoArgsCommand):
 
         """
         start_time = datetime.datetime.now()
-        self.logger.info(self.format_log_message('Looking for new ripple transactions since last run'))
+        self.logger.info(self.format_log_message(
+                'Looking for new ripple transactions since last run'))
         ledger_min_index = get_min_ledger_index()
         marker = None
         has_results = True
+        try: timeout = settings.RIPPLE_TIMEOUT
+        except AttributeError: timeout = 5
+
         while has_results:
             try:
-                response = account_tx(settings.RIPPLE_ACCOUNT, ledger_min_index, limit=200, marker=marker)
-                self.logger.info(self.format_log_message(response))
+                response = account_tx(settings.RIPPLE_ACCOUNT, 
+                                      ledger_min_index, limit=200, 
+                                      marker=marker,
+                                      timeout=timeout)
+                # self.logger.info(self.format_log_message(response))
             except (RippleApiError, ConnectionError), e:
                 self.logger.error(self.format_log_message(e))
                 break
@@ -65,7 +75,8 @@ class Command(NoArgsCommand):
 
             for transaction in transactions:
                 tr_tx = transaction['tx']
-                amount = tr_tx.get('Amount', {})
+                meta = tr_tx.get('meta', {})
+                amount = meta.get('DeliveredAmount') or tr_tx.get('Amount', {})
 
                 unprocessed_unstored_transactions = (
                     tr_tx['TransactionType'] == 'Payment' and
@@ -89,14 +100,14 @@ class Command(NoArgsCommand):
                             currency=amount['currency'],
                             issuer=amount['issuer'], value=amount['value']
                         )
-                        self.logger.info(self.format_log_message("Transaction saved: %s", transaction_object))
-            if (datetime.datetime.now() - start_time >= datetime.timedelta(seconds=270) and
-               has_results):
+                        self.logger.info(self.format_log_message(
+                                "Transaction saved: %s", transaction_object))
+            if (datetime.datetime.now() - start_time 
+                >= datetime.timedelta(seconds=270) and has_results):
                 has_results = False
                 self.logger.error(
-                    'Process_transactions command terminated because (270 seconds) timeout: '
-                    + unicode(marker))
-
+                    'Process_transactions command terminated because '
+                    '(270 seconds) timeout: ' + unicode(marker))
 
     def check_submitted_transactions(self):
         """
@@ -143,8 +154,8 @@ class Command(NoArgsCommand):
             self.logger.info(self.format_log_message('Submit: %s', transaction))
             submit_task.apply((transaction,))
 
-    def retry_failed_transactions(self):
-        self.logger.info('Retrying failed transactions')
-        for transaction in Transaction.objects.filter(status=Transaction.FAILURE):
-            self.logger.info(self.format_log_message('Found %s', transaction))
-            sign_task.apply((transaction, settings.RIPPLE_SECRET), link=submit_task.s())
+    #def retry_failed_transactions(self):
+    #    self.logger.info('Retrying failed transactions')
+    #    for transaction in Transaction.objects.filter(status=Transaction.FAILURE):
+    #        self.logger.info(self.format_log_message('Found %s', transaction))
+    #        sign_task.apply((transaction, settings.RIPPLE_SECRET), link=submit_task.s())
